import { __decorate } from "tslib";
import { css, html, observable, repeat } from '@microsoft/fast-element';
import { FoundationElement } from '@microsoft/fast-foundation';
import { setValueWithAccessor } from './utils';
export class SelectRenderer extends FoundationElement {
    constructor() {
        super(...arguments);
        this.selectionChanged = (e) => {
            this.value = e.target.value;
            this.params.onSelect(e.target.value, this.params);
        };
    }
    init(params) {
        var _a;
        if (!params)
            return;
        this.params = params;
        this.value = setValueWithAccessor((_a = params.node) === null || _a === void 0 ? void 0 : _a.data, params.accessor) || undefined;
    }
    getGui() {
        return this;
    }
    destroy() { }
    refresh(params) {
        return true;
    }
}
__decorate([
    observable
], SelectRenderer.prototype, "params", void 0);
__decorate([
    observable
], SelectRenderer.prototype, "value", void 0);
export const agSelectRendererStyles = css `
  :host,
  .select-renderer,
  zero-option,
  ::part(listbox),
  ::part(control) {
    max-width: var(--select-renderer-max-width);
    min-width: 100%;
  }
`;
export const getSelectRendererTemplate = (designSystem = 'foundation') => {
    const selectComponent = `${designSystem}-select`;
    const optionComponent = `${designSystem}-option`;
    return html `
    <${selectComponent}
      class="select-renderer"
      @change=${(x, c) => x.selectionChanged(c.event)}
      :value=${(x) => x.value}
    >
      <${optionComponent}
        defaultSelected
        style="display: none;"
      >
        ${(x) => x.params.defaultValue || 'Select option'}
      </${optionComponent}>
      ${repeat((x) => x.params.options(x.params.node.data), html `
        <${optionComponent} value=${(x) => x.name}>${(x) => x.displayName}</${optionComponent}>
      `)}
    </${selectComponent}>
  `;
};
export const foundationAgSelectRenderer = SelectRenderer.compose({
    baseName: 'select-renderer',
    styles: agSelectRendererStyles,
    template: getSelectRendererTemplate(),
});
