import { __decorate } from "tslib";
import { sync } from '@genesislcap/foundation-utils';
import { css, html, observable, ref } from '@microsoft/fast-element';
import { FoundationElement } from '@microsoft/fast-foundation';
import { setValueWithAccessor } from './utils';
export class AgTextRenderer extends FoundationElement {
    constructor() {
        super(...arguments);
        // Text field value
        this.textValue = '';
        /**
         * On text change handler
         * @param e CustomEvent
         */
        this.textChanged = (e) => {
            this.textValue = e.target.value;
            this.params.onChange(e.target.value, this.params);
        };
    }
    init(params) {
        var _a;
        if (!params)
            return;
        this.params = params;
        this.textValue =
            this.textValue === ''
                ? setValueWithAccessor((_a = params === null || params === void 0 ? void 0 : params.node) === null || _a === void 0 ? void 0 : _a.data, params.accessor)
                : this.textValue;
    }
    getGui() {
        return this;
    }
    destroy() { }
    refresh(params) {
        return true;
    }
}
__decorate([
    observable
], AgTextRenderer.prototype, "textValue", void 0);
__decorate([
    observable
], AgTextRenderer.prototype, "params", void 0);
export const textRendererStyles = css `
  :host {
    display: flex;
    width: 100%;
    height: 100%;
    align-center: center;
  }
  .text-renderer {
    width: 100%;
  }
`;
export const getTextRendererTemplate = (designSystem = 'foundation') => {
    const textComponent = `${designSystem}-text-field`;
    return html `
    <${textComponent}
      ${ref('textField')}
      type="text"
      class="text-renderer"
      :value="${sync((x) => x.textValue)}"
      @change="${(x, c) => x.textChanged(c.event)}"
    ></${textComponent}>
  `;
};
/**
 * The Foundation Text Renderer
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-grid-text-renderer\>
 */
export const foundationAgTextRenderer = AgTextRenderer.compose({
    baseName: 'grid-text-renderer',
    styles: textRendererStyles,
    template: getTextRendererTemplate(),
});
